==> nextcloud-18.0.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/privacy/l10n/sk.js <==
OC.L10N.register(
    "privacy",
    {
    "Privacy" : "Ochrana osobných údajov",
    "-" : "–",
    "The privacy center shows you where your data is stored and who can access it, either because you shared with them or because they are administrators." : "Centrum ochrany osobných údajov vám ukáže, kde sú vaše údaje uložené a kto k nim má prístup, buď preto, že ste ich niekomu sprístupnili vy alebo boli sprístupnené správcami.",
    "Remove external admin" : "Odobrať externého správcu",
    "Add external admin" : "Pridať externého správcu",
    "Your files are not protected by encryption." : "Vaše súbory nie sú chránené šifrovaním.",
    "Your files are encrypted with {linkopen}server-side-encryption ↗{linkclose}." : "Vaše súbory sú šifrované pomocou {linkopen}server-side-encryption ↗{linkclose}.",
    "This server is protected with full-disk-encryption." : "Tento server je chránený šifrovaním celého úložiska.",
    "Your files are encrypted with {linkopen}server-side-encryption ↗{linkclose}. Additionally, this server is protected with full-disk-encryption." : "Vaše súbory sú šifrované pomocou {linkopen}server-side-encryption ↗{linkclose}. Navyše je tento server chránený šifrovaním celého úložiska.",
    "This server is using full-disk-encryption." : "Tento server používa šifrovanie celého úložiska.",
    "Change data location" : "Zmena umiestnenia údajov",
    "Your data is located in: " : "Vaše dáta sa nachádzajú v:",
    "The admin hasn't selected the location of the server yet." : "Správca zatiaľ nezadal umiestnenie servera.",
    "Please select a country" : "Prosím vyberte krajinu",
    "You don't have any shares with individual users." : "Nesprístupňujete žiadne súbory iným používateľom.",
    "Somaliland" : "Soomaalilandská republika",
    "United Arab Emirates" : "Spojené Arabské Emiráty",
    "Afghanistan" : "Afganistan",
    "Albania" : "Albánsko",
    "Armenia" : "Arménsko",
    "Angola" : "Angola",
    "Argentina" : "Argentína",
    "Austria" : "Rakúsko",
    "Australia" : "Austrália",
    "Azerbaijan" : "Azerbajdžan",
    "Bosnia and Herzegowina" : "Bosna a Hercegovina",
    "Bangladesh" : "Bangladéš",
    "Belgium" : "Belgicko",
    "Burkina Faso" : "Burkina Faso",
    "Bulgaria" : "Bulharsko",
    "Burundi" : "Burundi",
    "Benin" : "Benin",
    "Brunei" : "Brunej",
    "Bolivia" : "Bolívia",
    "Brazil" : "Brazília",
    "Bahamas" : "Bahamské ostrovy",
    "Bhutan" : "Bhután",
    "Botswana" : "Botswana",
    "Belarus" : "Bielorusko",
    "Belize" : "Belize",
    "Canada" : "Kanada",
    "Democratic Republic of the Congo" : "Konžská demokratická republika",
    "Central African Republic" : "Stredoafrická republika",
    "Congo" : "Kongo",
    "Switzerland" : "Švajčiarsko",
    "Cote d'Ivoire" : "Pobrežie slonoviny",
    "Chile" : "Chile",
    "Cameroon" : "Kamerun",
    "China" : "Čína",
    "Colombia" : "Kolumbia",
    "Costa Rica" : "Kostarika",
    "Cuba" : "Kuba",
    "Cyprus" : "Cyprus",
    "Czech" : "Česká republika",
    "Germany" : "Nemecko",
    "Djibouti" : "Džibutsko",
    "Denmark" : "Dánsko",
    "Dominican Republic" : "Dominikánska republika",
    "Algeria" : "Alžírsko",
    "Ecuador" : "Ekvádor",
    "Estonia" : "Estónsko",
    "Egypt" : "Egypt",
    "West Sahara" : "Západná Sahara",
    "Eritrea" : "Eritrea",
    "Spain" : "Španielsko",
    "Ethiopia" : "Etiópia",
    "Finland" : "Fínsko",
    "Fiji" : "Fidži",
    "Falkland Islands" : "Falklandské ostrovy",
    "France" : "Francúzsko",
    "Gabon" : "Gabon",
    "United Kingdom" : "Spojené kráľovstvo",
    "Georgia" : "Gruzínsko",
    "Ghana" : "Ghana",
    "Greenland" : "Grónsko",
    "Gambia" : "Gambia",
    "Guinea" : "Guinea",
    "Equatorial Guinea" : "Rovníková Guinea",
    "Greece" : "Grécko",
    "Guatemala" : "Guatemala",
    "Guinea-Bissau" : "Guinea-Bissau",
    "Guyana" : "Guyana",
    "Honduras" : "Honduras",
    "Croatia" : "Chorvátsko",
    "Haiti" : "Haiti",
    "Hungary" : "Maďarsko",
    "Indonesia" : "Indonézia",
    "Ireland" : "Írsko",
    "Israel" : "Izrael",
    "India" : "India",
    "Iraq" : "Irak",
    "Iran" : "Irán",
    "Iceland" : "Island",
    "Italy" : "Taliansko",
    "Jamaica" : "Jamajka",
    "Jordan" : "Jordánsko",
    "Japan" : "Japonsko",
    "Kenya" : "Keňa",
    "Kyrgyzstan" : "Kirgizsko",
    "Cambodia" : "Kambodža",
    "North Korea" : "Severná Korea",
    "South Korea" : "Južná Kórea",
    "Kuwait" : "Kuvajt",
    "Kazakhstan" : "Kazachstan",
    "Laos" : "Laos",
    "Lebanon" : "Libanon",
    "Sri Lanka" : "Srí Lanka",
    "Liberia" : "Libéria",
    "Lesotho" : "Lesothské kráľovstvo",
    "Lithuania" : "Litva",
    "Luxembourg" : "Luxembursko",
    "Latvia" : "Lotyšsko",
    "Libya" : "Líbia",
    "Morocco" : "Maroko",
    "Moldova" : "Moldavsko",
    "Montenegro" : "Čierna Hora",
    "Madagascar" : "Madagaskar",
    "Macedonia" : "Macedónsko",
    "Mali" : "Mali",
    "Myanmar" : "Mjanmarsko",
    "Mongolia" : "Mongolsko",
    "Mauritania" : "Mauritánia",
    "Malawi" : "Malawi",
    "Mexico" : "Mexiko",
    "Malaysia" : "Malajzia",
    "Mozambique" : "Mozambik",
    "Namibia" : "Namíbia",
    "New Caledonia" : "Nová Kaledónia",
    "Niger" : "Niger",
    "Nigeria" : "Nigéria",
    "Nicaragua" : "Nikaragua",
    "Netherlands" : "Holandsko",
    "Norway" : "Nórsko",
    "Nepal" : "Nepál",
    "New Zealand" : "Nový Zéland",
    "Oman" : "Omán",
    "Panama" : "Panama",
    "Peru" : "Peru",
    "Papua New Guinea" : "Papua-Nová Guinea",
    "Philippines" : "Filipíny",
    "Pakistan" : "Pakistan",
    "Poland" : "Poľsko",
    "Puerto Rico" : "Portoriko",
    "Portugal" : "Portugalsko",
    "Paraguay" : "Paraguaj",
    "Qatar" : "Katar",
    "Romania" : "Rumunsko",
    "Serbia" : "Srbsko",
    "Russia" : "Rusko",
    "Rwanda" : "Rwanda",
    "Saudi Arabia" : "Saudská Arábia",
    "Solomon Islands" : "Šalamúnove ostrovy",
    "Sudan" : "Sudán",
    "Sweden" : "Švédsko",
    "Singapore" : "Singapur",
    "Slovenia" : "Slovinsko",
    "Slovakia" : "Slovensko",
    "Sierra Leone" : "Sierra Leone",
    "Senegal" : "Senegal",
    "Somalia" : "Somálsko",
    "Suriname" : "Surinam",
    "South Sudan" : "Južný Sudán",
    "El Salvador" : "Salvádor",
    "Syria" : "Sýria",
    "Swaziland" : "Svazijsko",
    "Chad" : "Čad",
    "Fr. S. Antarctic Lands" : "Francúzske južné a antarktické územia",
    "Togo" : "Togo",
    "Thailand" : "Thajsko",
    "Tajikistan" : "Tadžikistan",
    "Timor-Leste" : "Východný Timor",
    "Turkmenistan" : "Turkménsko",
    "Tunisia" : "Tunisko",
    "Turkey" : "Turecko",
    "Trinidad and Tobago" : "Trinidad a Tobago",
    "Taiwan" : "Taiwan",
    "Tanzania" : "Tanzánia",
    "Ukraine" : "Ukrajina",
    "Uganda" : "Uganda",
    "United States" : "Spojené štáty",
    "Uruguay" : "Uruguaj",
    "Uzbekistan" : "Uzbekistan",
    "Venezuela" : "Venezuela",
    "Vietnam" : "Vietnam",
    "Vanuatu" : "Vanuatu",
    "Yemen" : "Jemen",
    "South Africa" : "Juhoafrická republika",
    "Zambia" : "Zambia",
    "Zimbabwe" : "Zimbabwe",
    "Your Nextcloud account" : "Váš Nextcloud účet",
    "Your data represents who you are and can easily be abused. We at Nextcloud believe that you have a right to decide what happens with your data. Nextcloud protects your rights as defined in the User Data Manifesto!" : "Vaše údaje predstavujú kto ste a môžu byť ľahko zneužité. My v spoločnosti Nextcloud veríme, že máte právo rozhodnúť sa, ako sa bude s nimi nakladať. Nextcloud chráni vaše práva definované v Manifeste o používateľských údajoch.",
    "User Data Manifesto 2.0" : "Manifest o používateľských údajoch, verzia 2.0",
    "Defining basic rights for people to control their own data in the internet age" : "Definovanie základných práv ľudí na kontrolu vlastných údajov vo veku internetu",
    "Control" : "Riadenie",
    "over user data access" : "nad prístupom k údajom používateľa",
    "Data explicitly and willingly uploaded by a user should be under the ultimate control of the user. Users should be able to decide whom to grant direct access to their data and with which permissions and licenses such access should be granted." : "Údaje výslovne a dobrovoľne odovzdané používateľom by mali byť pod konečnou kontrolou používateľa. Používatelia by mali mať možnosť rozhodnúť sa, komu udelia priamy prístup k svojim údajom a s ktorými povoleniami a licenciami by sa mal takýto prístup udelovať.",
    "Knowledge" : "Znalosť",
    "of how the data is stored" : "ako sú údaje uchovávané",
    "When the data is uploaded to a specific service provider, users should be informed about where that specific service provider stores the data, how long, in which jurisdiction the specific service provider operates, and which laws apply." : "Keď sa údaje nahrávajú ku konkrétnemu poskytovateľovi služieb, používatelia by mali byť informovaní o tom, kde tento poskytovateľ služieb ukladá tieto údaje, ako dlho, v akej jurisdikcii konkrétny poskytovateľ služieb pôsobí a aké právne predpisy sa voči týmto údajom uplatňujú.",
    "Freedom" : "Sloboda",
    "to choose a platform" : "zvoliť si platformu",
    "Users should always be able to extract their data from the service at any time without experiencing any vendor lock-in. Open standards for formats and protocols are necessary to guarantee this." : "Používatelia by mali mať vždy možnosť extrahovať svoje údaje zo služby kedykoľvek, bez toho, aby pri tom narazili na nepostrádateľnosť od výrobcu resp. poskytovateľa. Na zabezpečenie tohto sú potrebné otvorené normy pre formáty a protokoly.",
    "Learn more ↗" : "Viac informácií ↗",
    "Where is your data?" : "Kde sa nachádzajú vaše dáta?",
    "Who has access to your data?" : "Kto má prístup v vašim dátam?",
    "Administrators" : "Administrátori",
    "People you shared with" : "Ľudia s ktorými ste zdieľali",
    "Privacy policy" : "Zásady ochrany osobných údajov",
    "Read the privacy policy." : "Prečítať si zásady ochrany osobných údajov",
    "Encryption" : "Šifrovanie"
},
"nplurals=4; plural=(n % 1 == 0 && n == 1 ? 0 : n % 1 == 0 && n >= 2 && n <= 4 ? 1 : n % 1 != 0 ? 2: 3);");

==> nextcloud-25.0.3-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/privacy/l10n/sk.js <==
OC.L10N.register(
    "privacy",
    {
    "Privacy" : "Ochrana osobných údajov",
    "-" : "–",
    "The privacy center shows you where your data is stored and who can access it, either because you shared with them or because they are administrators." : "Centrum ochrany osobných údajov vám ukáže, kde sú vaše údaje uložené a kto k nim má prístup, buď preto, že ste ich niekomu sprístupnili vy alebo boli sprístupnené správcami.",
    "Remove external admin" : "Odobrať externého správcu",
    "Add external admin" : "Pridať externého správcu",
    "Name of external admin" : "Meno externého správcu",
    "This server is using full-disk-encryption." : "Tento server používa šifrovanie celého úložiska.",
    "Your files on external storages may be encrypted using {linkopen}server-side-encryption ↗{linkclose} with a master key based on their configuration." : "Vaše súbory na externých úložiskách môžu byť šifrované pomocou {linkopen} šifrovania na strane servera ↗ {linkclose} s hlavným kľúčom na základe ich konfigurácie.",
    "Your files on external storages may be encrypted using {linkopen}server-side-encryption ↗{linkclose} with an individual key based on their configuration." : "Vaše súbory vo externých úložiskách môžu byť šifrované pomocou {linkopen} šifrovania na strane servera ↗ {linkclose} s individuálnym kľúčom na základe ich konfigurácie.",
    "Additionally, this server is protected with full-disk-encryption." : "Naviac, tento server je chránený šifrovaním celého úložiska.",
    "This server is protected with full-disk-encryption." : "Tento server je chránený šifrovaním celého úložiska.",
    "Your files are not protected by encryption." : "Vaše súbory nie sú chránené šifrovaním.",
    "Your data is located in:" : "Vaše dáta sa nachádzajú v:",
    "The admin has not selected the location of the server yet." : "Správca zatiaľ nezadal umiestnenie servera.",
    "Change data location" : "Zmena umiestnenia údajov",
    "Please select a region" : "Vyberte oblasť",
    "You don't have any shares with individual users." : "Nesprístupňujete žiadne súbory iným používateľom.",
    "Somaliland" : "Soomaalilandská republika",
    "Andorra" : "Andorra",
    "United Arab Emirates" : "Spojené Arabské Emiráty",
    "Afghanistan" : "Afganistan",
    "Antigua and Barbuda" : "Antigua a Barbuda",
    "Anguilla" : "Anguilla",
    "Albania" : "Albánsko",
    "Armenia" : "Arménsko",
    "Angola" : "Angola",
    "Antarctica" : "Antarktída",
    "Argentina" : "Argentína",
    "American Samoa" : "Americká Samo",
    "Austria" : "Rakúsko",
    "Australia" : "Austrália",
    "Aruba" : "Aruba",
    "Åland Islands" : "Alandy",
    "Azerbaijan" : "Azerbajdžan",
    "Bosnia and Herzegovina" : "Bosna a Hercegovina",
    "Barbados" : "Barbados",
    "Bangladesh" : "Bangladéš",
    "Belgium" : "Belgicko",
    "Burkina Faso" : "Burkina Faso",
    "Bulgaria" : "Bulharsko",
    "Bahrain" : "Bahrain",
    "Burundi" : "Burundi",
    "Benin" : "Benin",
    "Saint Barthélemy" : "Svätý Bartolomej",
    "Bermuda" : "Bermudy",
    "Brunei" : "Brunej",
    "Bolivia" : "Bolívia",
    "Bonaire, Sint Eustatius and Saba" : "Bonaire, Sint Eustatius a Saba",
    "Brazil" : "Brazília",
    "Bahamas" : "Bahamské ostrovy",
    "Bhutan" : "Bhután",
    "Bouvet Island" : "Bouvetský ostrov",
    "Botswana" : "Botswana",
    "Belarus" : "Bielorusko",
    "Belize" : "Belize",
    "Canada" : "Kanada",
    "Cocos (Keeling) Islands" : "Kokosové ostrovy",
    "Democratic Republic of the Congo" : "Konžská demokratická republika",
    "Central African Republic" : "Stredoafrická republika",
    "Congo" : "Kongo",
    "Switzerland" : "Švajčiarsko",
    "Cote d'Ivoire" : "Pobrežie slonoviny",
    "Cook Islands" : "Cookove ostrovy",
    "Chile" : "Chile",
    "Cameroon" : "Kamerun",
    "China" : "Čína",
    "Colombia" : "Kolumbia",
    "Costa Rica" : "Kostarika",
    "Cuba" : "Kuba",
    "Cabo Verde" : "Kapverdy",
    "Curaçao" : "Curaçao",
    "Christmas Island" : "Vianočný ostrov",
    "Cyprus" : "Cyprus",
    "Czech" : "Česká republika",
    "Germany" : "Nemecko",
    "Djibouti" : "Džibutsko",
    "Denmark" : "Dánsko",
    "Dominican Republic" : "Dominikánska republika",
    "Algeria" : "Alžírsko",
    "Ecuador" : "Ekvádor",
    "Estonia" : "Estónsko",
    "Egypt" : "Egypt",
    "West Sahara" : "Západná Sahara",
    "Eritrea" : "Eritrea",
    "Spain" : "Španielsko",
    "Ethiopia" : "Etiópia",
    "Finland" : "Fínsko",
    "Fiji" : "Fidži",
    "Falkland Islands" : "Falklandské ostrovy",
    "Micronesia" : "Mikronézia",
    "Faroe Islands" : "Faerské ostrovy",
    "France" : "Francúzsko",
    "Gabon" : "Gabon",
    "United Kingdom" : "Spojené kráľovstvo",
    "Grenada" : "Grenada",
    "Georgia" : "Gruzínsko",
    "French Guiana" : "Francúzska Guiana",
    "Guernsey" : "Guernsey",
    "Ghana" : "Ghana",
    "Gibraltar" : "Gibraltár",
    "Greenland" : "Grónsko",
    "Gambia" : "Gambia",
    "Guinea" : "Guinea",
    "Guadeloupe" : "Guadeloupe",
    "Equatorial Guinea" : "Rovníková Guinea",
    "Greece" : "Grécko",
    "South Georgia and the South Sandwich Islands" : "Južná Georgia a Južné Sandwichove ostrovy",
    "Guatemala" : "Guatemala",
    "Guam" : "Guam",
    "Guinea-Bissau" : "Guinea-Bissau",
    "Guyana" : "Guyana",
    "Honduras" : "Honduras",
    "Hong Kong" : "Hong Kong",
    "Heard Island and McDonald Islands" : "Heardove a McDonaldove ostrovy",
    "Croatia" : "Chorvátsko",
    "Haiti" : "Haiti",
    "Hungary" : "Maďarsko",
    "Indonesia" : "Indonézia",
    "Ireland" : "Írsko",
    "Israel" : "Izrael",
    "Isle of Man" : "ostrov Man",
    "India" : "India",
    "British Indian Ocean Territory" : "Britské indickooceánske územie",
    "Iraq" : "Irak",
    "Iran" : "Irán",
    "Iceland" : "Island",
    "Italy" : "Taliansko",
    "Jamaica" : "Jamajka",
    "Jordan" : "Jordánsko",
    "Japan" : "Japonsko",
    "Kenya" : "Keňa",
    "Kyrgyzstan" : "Kirgizsko",
    "Cambodia" : "Kambodža",
    "Kiribati" : "Kiribati",
    "Comores" : "Komory",
    "Saint Kitts and Nevis" : "Svätý Krištof a Nevis",
    "North Korea" : "Severná Korea",
    "South Korea" : "Južná Kórea",
    "Kuwait" : "Kuvajt",
    "Cayman Islands" : "Kajmanské ostrovy",
    "Kazakhstan" : "Kazachstan",
    "Laos" : "Laos",
    "Lebanon" : "Libanon",
    "Saint Lucia" : "Svätá Lucia",
    "Liechtenstein" : "Lichtenštajnsko",
    "Sri Lanka" : "Srí Lanka",
    "Liberia" : "Libéria",
    "Lesotho" : "Lesothské kráľovstvo",
    "Lithuania" : "Litva",
    "Luxembourg" : "Luxembursko",
    "Latvia" : "Lotyšsko",
    "Libya" : "Líbia",
    "Morocco" : "Maroko",
    "Monaco" : "Monako",
    "Moldova" : "Moldavsko",
    "Montenegro" : "Čierna Hora",
    "Saint Martin" : "Svätý Martin",
    "Madagascar" : "Madagaskar",
    "Marshall Islands" : "Marshallove ostrovy",
    "Macedonia" : "Macedónsko",
    "Mali" : "Mali",
    "Myanmar" : "Mjanmarsko",
    "Mongolia" : "Mongolsko",
    "Macao" : "Makao",
    "Northern Mariana Islands" : "Severné Mariany",
    "Mauritania" : "Mauritánia",
    "Montserrat" : "Montserrat",
    "Malta" : "Malta",
    "Mauritius" : "Maurícius",
    "Maldives" : "Maledivy",
    "Malawi" : "Malawi",
    "Mexico" : "Mexiko",
    "Malaysia" : "Malajzia",
    "Mozambique" : "Mozambik",
    "Namibia" : "Namíbia",
    "New Caledonia" : "Nová Kaledónia",
    "Niger" : "Niger",
    "Norfolk Island" : "Norfolk Island",
    "Nigeria" : "Nigéria",
    "Nicaragua" : "Nikaragua",
    "Netherlands" : "Holandsko",
    "Norway" : "Nórsko",
    "Nepal" : "Nepál",
    "Nauru" : "Nauru",
    "Niue" : "Niue",
    "New Zealand" : "Nový Zéland",
    "Oman" : "Omán",
    "Panama" : "Panama",
    "Peru" : "Peru",
    "French Polynesia" : "Francúzska Polynézia",
    "Papua New Guinea" : "Papua-Nová Guinea",
    "Philippines" : "Filipíny",
    "Pakistan" : "Pakistan",
    "Poland" : "Poľsko",
    "Saint Pierre and Miquelon" : "Saint Pierre a Miquelon",
    "Pitcairn" : "Pitcairnove ostrovy",
    "Puerto Rico" : "Portoriko",
    "Palestine" : "Palestína",
    "Portugal" : "Portugalsko",
    "Palau" : "Palau",
    "Paraguay" : "Paraguaj",
    "Qatar" : "Katar",
    "Réunion" : "Reunion",
    "Romania" : "Rumunsko",
    "Serbia" : "Srbsko",
    "Russia" : "Rusko",
    "Rwanda" : "Rwanda",
    "Saudi Arabia" : "Saudská Arábia",
    "Solomon Islands" : "Šalamúnove ostrovy",
    "Seychelles" : "Seychely",
    "Sudan" : "Sudán",
    "Sweden" : "Švédsko",
    "Singapore" : "Singapur",
    "Saint Helena, Ascension and Tristan da Cunha" : "Svätá Helena, Ascension a Tristan da Cunha",
    "Slovenia" : "Slovinsko",
    "Svalbard and Jan Mayen" : "Svalbard and Jan Mayen",
    "Slovakia" : "Slovensko",
    "Sierra Leone" : "Sierra Leone",
    "San Marino" : "San Maríno",
    "Senegal" : "Senegal",
    "Somalia" : "Somálsko",
    "Suriname" : "Surinam",
    "South Sudan" : "Južný Sudán",
    "Sao Tome and Principe" : "Svätý Tomáš a Princov ostrov",
    "El Salvador" : "Salvádor",
    "Sint Maarten" : "Sint Maarten",
    "Syria" : "Sýria",
    "Swaziland" : "Svazijsko",
    "Turks and Caicos Islands" : "ostrovy Turks a Caicos",
    "Chad" : "Čad",
    "Fr. S. Antarctic Lands" : "Francúzske južné a antarktické územia",
    "Togo" : "Togo",
    "Thailand" : "Thajsko",
    "Tajikistan" : "Tadžikistan",
    "Tokelau" : "Tokelau",
    "Timor-Leste" : "Východný Timor",
    "Turkmenistan" : "Turkménsko",
    "Tunisia" : "Tunisko",
    "Tonga" : "Tonga",
    "Turkey" : "Turecko",
    "Trinidad and Tobago" : "Trinidad a Tobago",
    "Tuvalu" : "Tuvalu",
    "Taiwan" : "Taiwan",
    "Tanzania" : "Tanzánia",
    "Ukraine" : "Ukrajina",
    "Uganda" : "Uganda",
    "United States Minor Outlying Islands" : "Menšie odľahlé ostrovy Spojených štátov",
    "United States" : "Spojené štáty",
    "Uruguay" : "Uruguaj",
    "Uzbekistan" : "Uzbekistan",
    "Holy See" : "Vatikán",
    "Saint Vincent and the Grenadines" : "Svätý Vincent a Grenadíny",
    "Venezuela" : "Venezuela",
    "Virgin Islands (British)" : "Britské Panenské ostrovy",
    "Virgin Islands (U.S.)" : "Americké Panenské ostrovy",
    "Vietnam" : "Vietnam",
    "Vanuatu" : "Vanuatu",
    "Wallis and Futuna" : "Wallis and Futuna",
    "Samoa" : "Samoa",
    "Yemen" : "Jemen",
    "Mayotte" : "Mayotte",
    "South Africa" : "Juhoafrická republika",
    "Zambia" : "Zambia",
    "Zimbabwe" : "Zimbabwe",
    "Your %s account" : "Váš účet %s",
    "Your data represents who you are and can easily be abused. We at Nextcloud believe that you have a right to decide what happens with your data. Nextcloud protects your rights as defined in the User Data Manifesto!" : "Vaše údaje predstavujú kto ste a môžu byť ľahko zneužité. My v spoločnosti Nextcloud veríme, že máte právo rozhodnúť sa, ako sa bude s nimi nakladať. Nextcloud chráni vaše práva definované v Manifeste o používateľských údajoch.",
    "User Data Manifesto 2.0" : "Manifest o používateľských údajoch, verzia 2.0",
    "Defining basic rights for people to control their own data in the internet age" : "Definovanie základných práv ľudí na kontrolu vlastných údajov vo veku internetu",
    "Control" : "Riadenie",
    "over user data access" : "nad prístupom k údajom používateľa",
    "Data explicitly and willingly uploaded by a user should be under the ultimate control of the user. Users should be able to decide whom to grant direct access to their data and with which permissions and licenses such access should be granted." : "Údaje výslovne a dobrovoľne odovzdané používateľom by mali byť pod konečnou kontrolou používateľa. Používatelia by mali mať možnosť rozhodnúť sa, komu udelia priamy prístup k svojim údajom a s ktorými povoleniami a licenciami by sa mal takýto prístup udelovať.",
    "Knowledge" : "Znalosť",
    "of how the data is stored" : "ako sú údaje uchovávané",
    "When the data is uploaded to a specific service provider, users should be informed about where that specific service provider stores the data, how long, in which jurisdiction the specific service provider operates, and which laws apply." : "Keď sa údaje nahrávajú ku konkrétnemu poskytovateľovi služieb, používatelia by mali byť informovaní o tom, kde tento poskytovateľ služieb ukladá tieto údaje, ako dlho, v akej jurisdikcii konkrétny poskytovateľ služieb pôsobí a aké právne predpisy sa voči týmto údajom uplatňujú.",
    "Freedom" : "Sloboda",
    "to choose a platform" : "zvoliť si platformu",
    "Users should always be able to extract their data from the service at any time without experiencing any vendor lock-in. Open standards for formats and protocols are necessary to guarantee this." : "Používatelia by mali mať vždy možnosť extrahovať svoje údaje zo služby kedykoľvek, bez toho, aby pri tom narazili na nepostrádateľnosť od výrobcu resp. poskytovateľa. Na zabezpečenie tohto sú potrebné otvorené normy pre formáty a protokoly.",
    "Learn more ↗" : "Viac informácií ↗",
    "Where is your data?" : "Kde sa nachádzajú vaše dáta?",
    "Who has access to your data?" : "Kto má prístup v vašim dátam?",
    "Administrators" : "Administrátori",
    "People you shared with" : "Ľudia s ktorými ste zdieľali",
    "Privacy policy" : "Zásady ochrany osobných údajov",
    "Read the privacy policy." : "Prečítať si zásady ochrany osobných údajov",
    "Encryption" : "Šifrovanie",
    "Your home storage is encrypted using {linkopen}server-side-encryption ↗{linkclose} with a master key." : "Vaše domáce úložisko je šifrované pomocou {linkopen}server-side-encryption ↗{linkclose} s hlavným kľúčom.",
    "Your home storage is encrypted using {linkopen}server-side-encryption ↗{linkclose} with an individual user key." : "Vaše domáce úložisko je šifrované pomocou šifrovania {linkopen} na strane servera ↗ {linkclose} pomocou individuálneho používateľského kľúča."
},
"nplurals=4; plural=(n % 1 == 0 && n == 1 ? 0 : n % 1 == 0 && n >= 2 && n <= 4 ? 1 : n % 1 != 0 ? 2: 3);");
